import { ILarkSRConfig } from './larksr';
import { AppliParams } from './appli_params';
export interface UTLockInfo {
    checkUtLockMessage: string;
    checkUtLockResult: boolean;
    remainMinutes: number;
}
export interface GetTaskResult {
    adminViewer: number;
    appKey: string;
    appliId: string;
    appliType: number;
    city: string;
    clientIp: string;
    country: string;
    createDate: string;
    dcs: number;
    limitMaxFps: number;
    offScreen: number;
    playerListToggle: number;
    playerMode: number;
    province: string;
    publicIp: string;
    reserveFlag: number;
    serverId: string;
    serverIp: string;
    shareUrl: string;
    startAt: string;
    startParam: string;
    startProcType: number;
    status: number;
    taskId: string;
    updateDate: string;
    useGamepad: number;
    wm: number;
    textInputEventPrompt: number;
    audioInput: number;
    audioInputAutoStart: number;
    videoInput: number;
    videoInputAutoStart: number;
    liveStreaming: number;
    mobileKeyboardType?: number;
}
export interface StartAppInfo {
    appliId: string;
    appliType: number;
    appliName: string;
    taskId: string;
    renderServerIp: string;
    wsProxy: string;
    preferPublicIp: string;
    renderServerPort: number;
    renderSSLServerPort: number;
    initCursorMode: number;
    rttLimit: string;
    touchOperateMode: string;
    fullScreenMode: number;
    mobileForceLandscape: number;
    mobileFullScreenMode: number;
    language: string;
    noOperationTimeout: string;
    serverId: string;
    network: string;
    playerListToggle: number;
    bgColor: string;
    logLevel: string;
    mobileVirtualJoystick: number;
    initWinSize: number;
    taskStatus: number;
    mouseZoomDirection: number;
    useGamepad: number;
    rttLimitInterval: string;
    playerMode?: number;
    userType?: number;
    authCode?: string;
    nickName?: string;
    nickname?: string;
    appKey?: string;
    groupId?: string;
    initResolutionType?: number;
    useWebCodec?: number;
    preferDecoder?: string;
    mobileWebMenuType?: number;
}
declare type HostAppliGetUrlReturnParams = {
    appliId: string;
    appKey: string;
    timestamp: string;
    signature: string;
    groupId?: string;
};
export default class API {
    static CheckUTLockInfoPath: string;
    static GetTaskPATH: string;
    static ClientLogErrorPath: string;
    static GetStartInfoPath: string;
    private static PocHostApplGetUrl;
    private static TaskInfoClientStartedPath;
    private static PortMappingListPath;
    private static GetTouchCtrMappingPath;
    private static GetAppliListPath;
    private static RegionListPath;
    static HostAppliGetUrl(params: {
        appliId: string;
        playerMode?: number;
        userType?: number;
        authCode?: string;
        taskId?: string;
    }): Promise<{
        host: string;
        origin: string;
        params: HostAppliGetUrlReturnParams;
    }>;
    static GetStartInfo(serverAddress: string, params: {
        sdkId: string;
        appliId: string;
        playerMode?: number;
        userType?: number;
        authCode?: string;
        taskId?: string;
        clientMac?: string;
        groupId?: string;
        regionId?: string;
        targetServerIp?: string;
        appKey?: string;
        timestamp?: string;
        signature?: string;
    } | any): Promise<StartAppInfo>;
    static CheckUTLockInfo(config: ILarkSRConfig): Promise<UTLockInfo>;
    static GetTask(config: ILarkSRConfig, taskid: string): Promise<GetTaskResult>;
    static LogError(errorCode: number, errorMsg: string, params: string, config: ILarkSRConfig): void;
    static ClientInfo(config: ILarkSRConfig, params: AppliParams): void;
    static TaskInfoClientStarted(config: ILarkSRConfig, params: AppliParams): void;
    static PortMappingList(config: ILarkSRConfig): Promise<unknown>;
    static GetTouchCtrMapping(server: string, appliId?: string): Promise<unknown>;
    static GetAppliList(server: string, params: any): Promise<unknown>;
    static RegionList(server: string, params: any): Promise<unknown>;
    static heartbeat(server: string, taskId: string): Promise<unknown>;
    static joinParam(params: any): string;
}
export {};
